@@ -166,11 +166,11 @@ class ContentSecurityValidator:
         self.logger = logging.getLogger(f"{__name__}.ContentSecurityValidator")
         self.forbidden_patterns = [
             r'#import\s+["\']\.\./',           # Path traversal
-            r'#eval\s*\(',                     # Code execution
+            r'#eval\s*\(',                     # Code execution (only Typst #eval)
             r'subprocess\.',                   # System calls
             r'os\.system\s*\(',               # System calls
             r'exec\s*\(',                     # Code execution
-            r'eval\s*\(',                     # Code evaluation
+            r'^eval\s*\(',                    # Direct eval calls (start of line)
             r'__import__\s*\(',               # Dynamic imports
             r'open\s*\(["\'][^"\']*\.\.["\']', # File access with ..
             r'#include\s+["\'][^"\']*\.\.',   # Include with path traversal
@@ -179,7 +179,7 @@ class ContentSecurityValidator:
         self.suspicious_patterns = [
             r'#set\s+page\s*\(\s*width\s*:\s*["\'].*[<>]',  # HTML-like injection
             r'javascript\s*:',                               # JS-like injection
-            r'data\s*:',                                     # Data URLs
+            r'^data\s*:',                                    # Data URLs (start of line)
             r'file\s*://',                                   # File URLs
         ]
     
